using System; 

namespace Server.Items 
{ 
   public class TournyToken : Item 
   { 
      [Constructable] 
      public TournyToken() : this( 1 ) 
      { 
      } 

      [Constructable] 
      public TournyToken( int amountFrom, int amountTo ) : this( Utility.Random( amountFrom, amountTo - amountFrom ) ) 
      { 
      } 

      [Constructable] 
      public TournyToken( int amount ) : base( 0xEED ) 
      { 
         Name = "Tourny Token"; 
         Hue = 1266; 
         Stackable = true; 
         Weight = 0.0; 
         Amount = amount; 

      } 

      public TournyToken( Serial serial ) : base( serial ) 
      { 
      } 

      public override int GetDropSound() 
      { 
         if ( Amount <= 1 ) 
            return 0x2E4; 
         else if ( Amount <= 5 ) 
            return 0x2E5; 
         else 
            return 0x2E6; 
      } 

      protected override void OnAmountChange( int oldValue ) 
      { 
         TotalGold = (TotalGold - oldValue) + Amount; 
      } 

      public override void UpdateTotals() 
      { 
         base.UpdateTotals(); 

         SetTotalGold( this.Amount ); 
      } 

      public override Item Dupe( int amount ) 
      { 
         return base.Dupe( new TournyToken( amount ), amount ); 
      } 

      public override void Serialize( GenericWriter writer ) 
      { 
         base.Serialize( writer ); 

         writer.Write( (int) 0 ); // version 
      } 

      public override void Deserialize( GenericReader reader ) 
      { 
         base.Deserialize( reader ); 

         int version = reader.ReadInt(); 
      } 
   } 
}